@@ -297,24 +297,24 @@ static void _proc_arq_vlr_node2(struct osmo_fsm_inst *fi)
 {
 	struct proc_arq_priv *par = fi->priv;
 	struct vlr_subscr *vsub = par->vsub;
-	bool umts_aka;
 
 	LOGPFSM(fi, "%s()\n", __func__);
 
 	/* Continue with ciphering, if enabled.
-	 * If auth/ciph is optional and the HLR returned no auth info, continue without ciphering. */
+	 * If auth/ciph is optional and the HLR returned no auth info, continue without ciphering.
+	 * Also continue without ciphering, if ASCI call was requested. According to TS 143.068/069 Clause 7.3
+	 * ciphering has not been completely specified. The SIM does not support key storage. */
 	if (!is_cmc_smc_to_be_attempted(par)
-	    || (vsub->sec_ctx == VLR_SEC_CTX_NONE && !par->is_ciphering_required)) {
+	    || (vsub->sec_ctx == VLR_SEC_CTX_NONE && !par->is_ciphering_required)
+	    || par->cm_service_type == GSM48_CMSERV_VGCS
+	    || par->cm_service_type == GSM48_CMSERV_VBS) {
 		_proc_arq_vlr_node2_post_ciph(fi);
 		return;
 	}
 
 	switch (vsub->sec_ctx) {
 	case VLR_SEC_CTX_GSM:
-		umts_aka = false;
-		break;
 	case VLR_SEC_CTX_UMTS:
-		umts_aka = true;
 		break;
 	default:
 		LOGPFSML(fi, LOGL_ERROR, "Cannot start ciphering, security context is not established\n");
@@ -323,7 +323,7 @@ static void _proc_arq_vlr_node2(struct osmo_fsm_inst *fi)
 	}
 
 	if (vlr_set_ciph_mode(vsub->vlr, fi, par->msc_conn_ref,
-			      umts_aka,
+			      vsub->sec_ctx,
 			      vsub->vlr->cfg.retrieve_imeisv_ciphered)) {
 		LOGPFSML(fi, LOGL_ERROR,
 			 "Failed to send Ciphering Mode Command\n");
